# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingHeartRateAlertChangedEventType(str, enum.Enum):
    DAILY_DATA_HEART_RATE_ALERT_CREATED = "daily.data.heart_rate_alert.created"
    DAILY_DATA_HEART_RATE_ALERT_UPDATED = "daily.data.heart_rate_alert.updated"

    def visit(
        self,
        daily_data_heart_rate_alert_created: typing.Callable[[], T_Result],
        daily_data_heart_rate_alert_updated: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ClientFacingHeartRateAlertChangedEventType.DAILY_DATA_HEART_RATE_ALERT_CREATED:
            return daily_data_heart_rate_alert_created()
        if self is ClientFacingHeartRateAlertChangedEventType.DAILY_DATA_HEART_RATE_ALERT_UPDATED:
            return daily_data_heart_rate_alert_updated()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class AppointmentServiceType(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    APPOINTMENT_READY = "appointment-ready"
    APPOINTMENT_REQUEST = "appointment-request"

    def visit(
        self, appointment_ready: typing.Callable[[], T_Result], appointment_request: typing.Callable[[], T_Result]
    ) -> T_Result:
        if self is AppointmentServiceType.APPOINTMENT_READY:
            return appointment_ready()
        if self is AppointmentServiceType.APPOINTMENT_REQUEST:
            return appointment_request()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ContraceptiveEntryType(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    UNSPECIFIED = "unspecified"
    IMPLANT = "implant"
    INJECTION = "injection"
    IUD = "iud"
    INTRAVAGINAL_RING = "intravaginal_ring"
    ORAL = "oral"
    PATCH = "patch"

    def visit(
        self,
        unspecified: typing.Callable[[], T_Result],
        implant: typing.Callable[[], T_Result],
        injection: typing.Callable[[], T_Result],
        iud: typing.Callable[[], T_Result],
        intravaginal_ring: typing.Callable[[], T_Result],
        oral: typing.Callable[[], T_Result],
        patch: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ContraceptiveEntryType.UNSPECIFIED:
            return unspecified()
        if self is ContraceptiveEntryType.IMPLANT:
            return implant()
        if self is ContraceptiveEntryType.INJECTION:
            return injection()
        if self is ContraceptiveEntryType.IUD:
            return iud()
        if self is ContraceptiveEntryType.INTRAVAGINAL_RING:
            return intravaginal_ring()
        if self is ContraceptiveEntryType.ORAL:
            return oral()
        if self is ContraceptiveEntryType.PATCH:
            return patch()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class Race(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    AFRICAN_AMERICAN_OR_BLACK = "african_american_or_black"
    ASIAN = "asian"
    INDIGENOUS_NATIVE_AMERICAN_ALASKA_NATIVE = "indigenous_native_american_alaska_native"
    OTHER = "other"
    PACIFIC_ISLANDER_OR_HAWAIIAN = "pacific_islander_or_hawaiian"
    WHITE_CAUCASIAN = "white_caucasian"

    def visit(
        self,
        african_american_or_black: typing.Callable[[], T_Result],
        asian: typing.Callable[[], T_Result],
        indigenous_native_american_alaska_native: typing.Callable[[], T_Result],
        other: typing.Callable[[], T_Result],
        pacific_islander_or_hawaiian: typing.Callable[[], T_Result],
        white_caucasian: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is Race.AFRICAN_AMERICAN_OR_BLACK:
            return african_american_or_black()
        if self is Race.ASIAN:
            return asian()
        if self is Race.INDIGENOUS_NATIVE_AMERICAN_ALASKA_NATIVE:
            return indigenous_native_american_alaska_native()
        if self is Race.OTHER:
            return other()
        if self is Race.PACIFIC_ISLANDER_OR_HAWAIIAN:
            return pacific_islander_or_hawaiian()
        if self is Race.WHITE_CAUCASIAN:
            return white_caucasian()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class AttemptStatus(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    SUCCESS = "success"
    FAILURE = "failure"

    def visit(self, success: typing.Callable[[], T_Result], failure: typing.Callable[[], T_Result]) -> T_Result:
        if self is AttemptStatus.SUCCESS:
            return success()
        if self is AttemptStatus.FAILURE:
            return failure()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class Billing(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    CLIENT_BILL = "client_bill"
    COMMERCIAL_INSURANCE = "commercial_insurance"
    PATIENT_BILL_PASSTHROUGH = "patient_bill_passthrough"
    PATIENT_BILL = "patient_bill"

    def visit(
        self,
        client_bill: typing.Callable[[], T_Result],
        commercial_insurance: typing.Callable[[], T_Result],
        patient_bill_passthrough: typing.Callable[[], T_Result],
        patient_bill: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is Billing.CLIENT_BILL:
            return client_bill()
        if self is Billing.COMMERCIAL_INSURANCE:
            return commercial_insurance()
        if self is Billing.PATIENT_BILL_PASSTHROUGH:
            return patient_bill_passthrough()
        if self is Billing.PATIENT_BILL:
            return patient_bill()



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .ao_e import AoE
from .marker_type import MarkerType


class ClientFacingMarker(UniversalBaseModel):
    id: int
    name: str
    slug: str
    description: typing.Optional[str] = None
    lab_id: typing.Optional[int] = None
    provider_id: typing.Optional[str] = None
    type: typing.Optional[MarkerType] = None
    unit: typing.Optional[str] = None
    price: typing.Optional[str] = None
    aoe: typing.Optional[AoE] = None
    a_la_carte_enabled: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.providers import Providers
from ..types.user_historical_pulls_response import UserHistoricalPullsResponse
from ..types.user_resources_response import UserResourcesResponse
from .raw_client import AsyncRawIntrospectClient, RawIntrospectClient


class IntrospectClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawIntrospectClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawIntrospectClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawIntrospectClient
        """
        return self._raw_client

    def get_user_resources(
        self,
        *,
        user_id: typing.Optional[str] = None,
        provider: typing.Optional[Providers] = None,
        user_limit: typing.Optional[int] = None,
        cursor: typing.Optional[str] = None,
        next_cursor: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UserResourcesResponse:
        """
        Parameters
        ----------
        user_id : typing.Optional[str]

        provider : typing.Optional[Providers]

        user_limit : typing.Optional[int]

        cursor : typing.Optional[str]

        next_cursor : typing.Optional[str]
            The cursor for fetching the next page, or `null` to fetch the first page.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UserResourcesResponse
            Successful Response

        Examples
        --------
        from vital import Vital
        client = Vital(api_key="YOUR_API_KEY", )
        client.introspect.get_user_resources()
        """
        _response = self._raw_client.get_user_resources(
            user_id=user_id,
            provider=provider,
            user_limit=user_limit,
            cursor=cursor,
            next_cursor=next_cursor,
            request_options=request_options,
        )
        return _response.data

    def get_user_historical_pulls(
        self,
        *,
        user_id: typing.Optional[str] = None,
        provider: typing.Optional[Providers] = None,
        user_limit: typing.Optional[int] = None,
        cursor: typing.Optional[str] = None,
        next_cursor: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UserHistoricalPullsResponse:
        """
        Parameters
        ----------
        user_id : typing.Optional[str]

        provider : typing.Optional[Providers]

        user_limit : typing.Optional[int]

        cursor : typing.Optional[str]

        next_cursor : typing.Optional[str]
            The cursor for fetching the next page, or `null` to fetch the first page.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UserHistoricalPullsResponse
            Successful Response

        Examples
        --------
        from vital import Vital
        client = Vital(api_key="YOUR_API_KEY", )
        client.introspect.get_user_historical_pulls()
        """
        _response = self._raw_client.get_user_historical_pulls(
            user_id=user_id,
            provider=provider,
            user_limit=user_limit,
            cursor=cursor,
            next_cursor=next_cursor,
            request_options=request_options,
        )
        return _response.data


class AsyncIntrospectClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawIntrospectClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawIntrospectClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawIntrospectClient
        """
        return self._raw_client

    async def get_user_resources(
        self,
        *,
        user_id: typing.Optional[str] = None,
        provider: typing.Optional[Providers] = None,
        user_limit: typing.Optional[int] = None,
        cursor: typing.Optional[str] = None,
        next_cursor: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UserResourcesResponse:
        """
        Parameters
        ----------
        user_id : typing.Optional[str]

        provider : typing.Optional[Providers]

        user_limit : typing.Optional[int]

        cursor : typing.Optional[str]

        next_cursor : typing.Optional[str]
            The cursor for fetching the next page, or `null` to fetch the first page.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UserResourcesResponse
            Successful Response

        Examples
        --------
        from vital import AsyncVital
        import asyncio
        client = AsyncVital(api_key="YOUR_API_KEY", )
        async def main() -> None:
            await client.introspect.get_user_resources()
        asyncio.run(main())
        """
        _response = await self._raw_client.get_user_resources(
            user_id=user_id,
            provider=provider,
            user_limit=user_limit,
            cursor=cursor,
            next_cursor=next_cursor,
            request_options=request_options,
        )
        return _response.data

    async def get_user_historical_pulls(
        self,
        *,
        user_id: typing.Optional[str] = None,
        provider: typing.Optional[Providers] = None,
        user_limit: typing.Optional[int] = None,
        cursor: typing.Optional[str] = None,
        next_cursor: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UserHistoricalPullsResponse:
        """
        Parameters
        ----------
        user_id : typing.Optional[str]

        provider : typing.Optional[Providers]

        user_limit : typing.Optional[int]

        cursor : typing.Optional[str]

        next_cursor : typing.Optional[str]
            The cursor for fetching the next page, or `null` to fetch the first page.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UserHistoricalPullsResponse
            Successful Response

        Examples
        --------
        from vital import AsyncVital
        import asyncio
        client = AsyncVital(api_key="YOUR_API_KEY", )
        async def main() -> None:
            await client.introspect.get_user_historical_pulls()
        asyncio.run(main())
        """
        _response = await self._raw_client.get_user_historical_pulls(
            user_id=user_id,
            provider=provider,
            user_limit=user_limit,
            cursor=cursor,
            next_cursor=next_cursor,
            request_options=request_options,
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class SleepType(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    LONG_SLEEP = "long_sleep"
    SHORT_SLEEP = "short_sleep"
    ACKNOWLEDGED_NAP = "acknowledged_nap"
    UNKNOWN = "unknown"

    def visit(
        self,
        long_sleep: typing.Callable[[], T_Result],
        short_sleep: typing.Callable[[], T_Result],
        acknowledged_nap: typing.Callable[[], T_Result],
        unknown: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is SleepType.LONG_SLEEP:
            return long_sleep()
        if self is SleepType.SHORT_SLEEP:
            return short_sleep()
        if self is SleepType.ACKNOWLEDGED_NAP:
            return acknowledged_nap()
        if self is SleepType.UNKNOWN:
            return unknown()
